
# ⚓ Simple Discord.js Handler

## ⚓ Tutorial

### ❓ Getting Started
To get started, you need to install [NodeJs](https://nodejs.org) (recommended version) to ensure everything works during testing. For the code editor, I recommend [Visual Studio Code](https://code.visualstudio.com).

### ❓ Create a Discord Application
Go to the [Discord Developer Portal](https://discord.com/developers/applications) to create your application. Follow the instructions and keep the page open to retrieve the necessary information later.

### ❓ Installation
To install the module, run the following command (this is where NodeJs comes in handy):
```bash
npm install simple-djs-handler
```

### ❓ Bot Configuration
You need to initialize your main file (which we'll call `main.js`) with the following code:

```js
const BotClient = require('./index');

const client = new BotClient({
  token: "application_token",
  client_id: "application_client_id",
  logger: {
    app_id: "app_nodejs_CODE", // with node-ls.app/
    api_key: "CODE" // with node-ls.app/
  },
  intents: [/* ...your intents here... */]
});

// Loading commands from the "commands" folder
client.loadCommands('./commands');

// Loading commands from the "commands" folder
client.loadEvents('./events');

// Démarrage du bot
client.start();
```

- Replace `application_token` with your bot's token. For this, go to the **Bot** section on the Discord Developer Portal.
- Replace `application_client_id` with your bot's ID, available in the **General Information** section.

- Replace `app_nodejs_CODE` with your nodejs app with [node-ls.app](https://node-ls.app).
- Replace `CODE` with your app api key with [node-ls.app](https://node-ls.app).

Then, you can start your bot with the following command:
```bash
node main // or the name of your index file
```


### ❓ Command Configuration
Here is an example structure for a command without options:

```js
const { SlashCommandBuilder } = require('discord.js');

module.exports = {
  data: new SlashCommandBuilder()
    .setName('ping')
    .setDescription('Répond avec Pong!'),
  async execute(interaction) {
    await interaction.reply('Pong!');
  }
};
```